
TODO: TODO_65_62_32_33: extend data manipulation API by `del` and `invalidate`

Currently, there are initial implementations for `get` and `set` per query.

Implement support for:
*   `del` data per query
*   `invalidate` cache per query

Also, consider renaming `get` and `set` into `get_snapshot` and `set_snapshot`.

See also FS_74_69_61_79: get set data envelope.
